summaryrefslogtreecommitdiff
path: root/coverage/plugin.py
diff options
context:
space:
mode:
Diffstat (limited to 'coverage/plugin.py')
-rw-r--r--coverage/plugin.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/coverage/plugin.py b/coverage/plugin.py
index 5b38e336..8d149af9 100644
--- a/coverage/plugin.py
+++ b/coverage/plugin.py
@@ -359,12 +359,12 @@ class FileReporter:
Returns a Unicode string.
The base implementation simply reads the `self.filename` file and
decodes it as UTF8. Override this method if your file isn't readable
as a text file, or if you need other encoding support.
"""
with open(self.filename, "rb") as f:
- return f.read().decode("utf8")
+ return f.read().decode("utf-8")
def lines(self):
"""Get the executable lines in this file.
@@ -359,12 +359,12 @@ class FileReporter:
Returns a Unicode string.
The base implementation simply reads the `self.filename` file and
- decodes it as UTF8. Override this method if your file isn't readable
+ decodes it as UTF-8. Override this method if your file isn't readable
as a text file, or if you need other encoding support.
"""